import { IFormItem } from "@/components/CusForm";

export const formItems: IFormItem[] = [
  {
    label: "标题",
    prop: "title",
    type: "group",
    children: [
      {
        label: " ",
        prop: "showTitle",
        type: "checkboxGroup",
        fieldProps: {
          options: [{ label: "标题可见", value: true }],
        },
        defaultValue: []
      },
      {
        label: "文本",
        prop: "titleText",
        type: "input",
        defaultValue: "图表标题"
      },
      {
        label: "位置",
        prop: "titlePosition",
        type: "position",
        defaultValue: "center"
      },
      {
        label: "样式",
        prop: "titleStyle",
        type: "fontStyle",
        defaultValue: {
          size: 18,
          bold: true,
          italic: false,
          underline: false,
        }
      },
      {
        label: "背景",
        prop: "",
        type: "divider",
      },
      {
        label: "填充",
        prop: "titleBackground",
        type: "backgroundSelect",
        fieldProps: {
          filterOptions: ["image"],
        },
        defaultValue: {
          type: "color",
          color: "#fff",
        }
      },
      {
        label: "透明度",
        prop: "titleOpacity",
        type: "slider",
        defaultValue: 100
      },
      {
        label: "圆角",
        prop: "titleBorderRadius",
        type: "inputNumber",
        fieldProps: {
          addonAfter: "px",
        },
        defaultValue: 0
      },
    ],
  },
  {
    label: "图例",
    prop: "legend",
    type: "group",
    children: [
      {
        label: " ",
        prop: "showLegend",
        type: "checkboxGroup",
        fieldProps: {
          options: [{ label: "图例可见", value: true }],
        },
        defaultValue: [true]
      },
      {
        label: "位置",
        prop: "legendPosition",
        type: "position",
        fieldProps: {
          type: "round",
        },
        defaultValue: "top"
      },
      {
        label: "样式",
        prop: "legendStyle",
        type: "fontStyle",
        defaultValue: {
          size: 12,
          bold: false,
          italic: false,
          underline: false,
        }
      },
      {
        label: "边框",
        prop: "",
        type: "divider",
      },
      {
        label: "线宽",
        prop: "legendBorderWidth",
        type: "inputNumber",
        fieldProps: {
          addonAfter: "px",
        },
        defaultValue: 0
      },
      {
        label: "颜色",
        prop: "legendBorderColor",
        type: "colorSelect",
        defaultValue: "#ccc"
      },
      {
        label: "圆角",
        prop: "legendBorderRadius",
        type: "inputNumber",
        fieldProps: {
          addonAfter: "px",
        },
        defaultValue: 0
      },
      {
        label: "背景",
        prop: "",
        type: "divider",
      },
      {
        label: "背景",
        prop: "legendBackground",
        type: "backgroundSelect",
        fieldProps: {
          filterOptions: ["image"],
        },
        defaultValue: {
          type: "color",
          color: "#fff",
        }
      },
      {
        label: "背景透明度",
        prop: "legendBackgroudOpacity",
        type: "slider",
        defaultValue: 100
      },
      {
        label: "背景圆角",
        prop: "legendBackgroundRadius",
        type: "inputNumber",
        fieldProps: {
          addonAfter: "px",
        },
        defaultValue: 0
      },
      {
        label: "阴影",
        prop: "legendShadow",
        type: "radioGroup",
        fieldProps: {
          options: [
            { label: "开启", value: true },
            { label: "关闭", value: false },
          ],
        },
        defaultValue: false
      },
    ],
  },
  {
    label: "标签",
    prop: "label",
    type: "group",
    children: [
      {
        label: " ",
        prop: "showLabel",
        type: "checkboxGroup",
        fieldProps: {
          options: [{ label: "标签可见", value: true }],
        },
        defaultValue: false
      },
      {
        label: "文本",
        prop: "labelValueType",
        type: "checkboxGroup",
        fieldProps: {
          options: [
            { label: "分类名", value: 'category' },
            { label: "系列名", value: 'serie' },
            { label: "数值", value: 'value' },
            { label: "百分比", value: 'percent' },
          ]
        },
        defaultValue: ['value']
      },
      {
        label: "格式化",
        prop: "labelFormatter",
        type: "input",
        tip: "支持字符串模板和回调函数",
        defaultValue: "{value}"
      },
      {
        label: "颜色",
        prop: "labelColor",
        type: "colorSelect",
        defaultValue: "#000"
      },
      {
        label: "样式",
        prop: "labelStyle",
        type: "fontStyle",
        defaultValue: {
          size: 12,
          bold: false,
          italic: false,
          underline: false,
        }
      },
      {
        label: "布局",
        prop: "",
        type: "divider",
      },
      {
        label: "位置",
        prop: "labelPosition",
        type: "radioGroup",
        fieldProps: {
          options: [
            { label: "内部", value: "inside" },
            { label: "外部", value: "outside" },
            { label: "中间", value: "center" },
          ],
        },
        defaultValue: "outside"
      },
      {
        label: "文本方向",
        prop: "labelDirection",
        type: "radioGroup",
        fieldProps: {
          options: [
            { label: "水平", value: "horizontal" },
            { label: "垂直", value: "vertical" },
          ],
        },
        defaultValue: "horizontal"
      },
      {
        label: "边框",
        prop: "",
        type: "divider",
      },
      {
        label: "线宽",
        prop: "labelBorderWidth",
        type: "inputNumber",
        fieldProps: {
          addonAfter: "px",
        },
        defaultValue: 0
      },
      {
        label: "颜色",
        prop: "labelBorderColor",
        type: "colorSelect",
        defaultValue: "#ccc"
      },
      {
        label: "圆角",
        prop: "labelBorderRadius",
        type: "inputNumber",
        fieldProps: {
          addonAfter: "px",
        },
        defaultValue: 0
      },
    ],
  },
  {
    label: "系列",
    prop: "serie",
    type: "group",
    children: [
      {
        label: "配色",
        prop: "colorScheme",
        type: "colorScheme",
        defaultValue: "custom"
      },
      {
        label: "样式",
        prop: "",
        type: "divider",
      },
      {
        label: "固定柱宽",
        prop: "serieBarFixedWidth",
        type: "radioGroup",
        fieldProps: {
          options: [
            { label: "是", value: true },
            { label: "否", value: false },
          ],
        },
        defaultValue: false
      },
      {
        label: "系列间隔",
        prop: "serieGap",
        type: "slider",
        defaultValue: 20
      },
      {
        label: "分类间隔",
        prop: "categoryGap",
        type: "slider",
        defaultValue: 20
      },
      {
        label: "边框",
        prop: "",
        type: "divider",
      },
      {
        label: "线宽",
        prop: "serieBorderWidth",
        type: "inputNumber",
        fieldProps: {
          addonAfter: "px",
        },
        defaultValue: 0
      },
      {
        label: "颜色",
        prop: "serieBorderColor",
        type: "colorSelect",
        defaultValue: "#ccc"
      },
      {
        label: "圆角",
        prop: "serieBorderRadius",
        type: "inputNumber",
        fieldProps: {
          addonAfter: "px",
        },
        defaultValue: 0
      },
    ]
  },
  {
    label: "X 轴",
    prop: "xAxis",
    type: "group",
    children: [
      {
        label: "类型",
        prop: "xAxisType",
        type: "select",
        fieldProps: {
          options: [
            { label: "类目坐标轴", value: "category" },
            { label: "数值坐标轴", value: "value" },
            { label: "时间坐标轴", value: "time" },
          ],
        },
        defaultValue: "category"
      },
      {
        label: "轴标题",
        prop: "xAliasShowTitle",
        type: "radioGroup",
        fieldProps: {
          options: [
            { label: "显示", value: true },
            { label: "隐藏", value: false },
          ],
        },
        defaultValue: false
      },
      {
        label: "标题内容",
        prop: "xAliasTitle",
        type: "input",
        defaultValue: "X 轴标题"
      },
      {
        label: "标题位置",
        prop: "xAliasPosition",
        type: "position",
        defaultValue: "center"
      },
      {
        label: "标题样式",
        prop: "xAliasStyle",
        type: "fontStyle",
        defaultValue: {
          size: 12,
          bold: false,
          italic: false,
          underline: false,
        }
      },
      {
        label: "轴线",
        prop: "",
        type: "divider",
      },
      {
        label: "线宽",
        prop: "xAliasLineWidth",
        type: "inputNumber",
        fieldProps: {
          addonAfter: "px",
        },
        defaultValue: 1
      },
      {
        label: "颜色",
        prop: "xAliasLineColor",
        type: "colorSelect",
        defaultValue: "#ccc"
      },
      {
        label: "刻度",
        prop: "",
        type: "divider",
      },
      {
        label: "显示刻度",
        prop: "xAliasTickShow",
        type: "radioGroup",
        fieldProps: {
          options: [
            { label: "显示", value: true },
            { label: "隐藏", value: false },
          ],
        },
        defaultValue: true
      },
      {
        label: "刻度长度",
        prop: "xAliasTickLength",
        type: "inputNumber",
        fieldProps: {
          addonAfter: "px",
        },
        defaultValue: 5
      },
      {
        label: "刻度颜色",
        prop: "xAliasTickColor",
        type: "colorSelect",
        defaultValue: "#ccc"
      },
      {
        label: "标签",
        prop: "",
        type: "divider",
      },
      {
        label: "颜色",
        prop: "xAliasLabelColor",
        type: "colorSelect",
        defaultValue: "#000"
      },
      {
        label: "样式",
        prop: "xAliasLabelStyle",
        type: "fontStyle",
        defaultValue: {
          size: 12,
          bold: false,
          italic: false,
          underline: false,
        }
      },
    ]
  },
  {
    label: "Y 轴",
    prop: "yAxis",
    type: "group",
    children: [
      {
        label: "轴标题",
        prop: "yAliasShowTitle",
        type: "radioGroup",
        fieldProps: {
          options: [
            { label: "显示", value: true },
            { label: "隐藏", value: false },
          ],
        },
        defaultValue: false
      },
      {
        label: "标题内容",
        prop: "yAliasTitle",
        type: "input",
        defaultValue: "Y 轴标题"
      },
      {
        label: "标题位置",
        prop: "yAliasPosition",
        type: "position",
        defaultValue: "center"
      },
      {
        label: "标题样式",
        prop: "yAliasStyle",
        type: "fontStyle",
        defaultValue: {
          size: 12,
          bold: false,
          italic: false,
          underline: false,
        }
      },
      {
        label: "轴线",
        prop: "",
        type: "divider",
      },
      {
        label: "线宽",
        prop: "yAliasLineWidth",
        type: "inputNumber",
        fieldProps: {
          addonAfter: "px",
        },
        defaultValue: 1
      },
      {
        label: "颜色",
        prop: "yAliasLineColor",
        type: "colorSelect",
        defaultValue: "#ccc"
      },
      {
        label: "刻度",
        prop: "",
        type: "divider",
      },
      {
        label: "显示刻度",
        prop: "yAliasTickShow",
        type: "radioGroup",
        fieldProps: {
          options: [
            { label: "显示", value: true },
            { label: "隐藏", value: false },
          ],
        },
        defaultValue: true
      },
      {
        label: "刻度长度",
        prop: "yAliasTickLength",
        type: "inputNumber",
        fieldProps: {
          addonAfter: "px",
        },
        defaultValue: 5
      },
      {
        label: "刻度颜色",
        prop: "yAliasTickColor",
        type: "colorSelect",
        defaultValue: "#ccc"
      },
      {
        label: "标签",
        prop: "",
        type: "divider",
      },
      {
        label: "颜色",
        prop: "yAliasLabelColor",
        type: "colorSelect",
        defaultValue: "#000"
      },
      {
        label: "样式",
        prop: "yAliasLabelStyle",
        type: "fontStyle",
        defaultValue: {
          size: 12,
          bold: false,
          italic: false,
          underline: false,
        }
      },
    ]
  },
  {
    label: "提示",
    prop: "tooltip",
    type: "group",
    children: [
      {
        label: " ",
        prop: "showTooltip",
        type: "checkboxGroup",
        fieldProps: {
          options: [
            { label: "提示可见", value: true },
          ],
        },
        defaultValue: [true]
      },
      {
        label: "文本",
        prop: "tooltipValueType",
        type: "checkboxGroup",
        fieldProps: {
          options: [
            { label: "分类名", value: 'category' },
            { label: "系列名", value: 'serie' },
            { label: "数值", value: 'value' },
            { label: "百分比", value: 'percent' },
          ]
        },
        defaultValue: ['value']
      },
      {
        label: "格式化",
        prop: "tooltipFormatter",
        type: "input",
        tip: "支持字符串模板和回调函数",
        defaultValue: "{value}"
      },
      {
        label: "样式",
        prop: "tooltipStyle",
        type: "fontStyle",
        defaultValue: {
          size: 12,
          bold: false,
          italic: false,
          underline: false,
        }
      },
      {
        label: "边框",
        prop: "",
        type: "divider",
      },
      {
        label: "线宽",
        prop: "tooltipBorderWidth",
        type: "inputNumber",
        fieldProps: {
          addonAfter: "px",
        },
        defaultValue: 1
      },
      {
        label: "颜色",
        prop: "tooltipBorderColor",
        type: "colorSelect",
        defaultValue: "#ccc"
      },
      {
        label: "圆角",
        prop: "tooltipBorderRadius",
        type: "inputNumber",
        fieldProps: {
          addonAfter: "px",
        },
        defaultValue: 0
      },
      {
        label: "背景",
        prop: "",
        type: "divider",
      },
      {
        label: "填充",
        prop: "tooltipBackground",
        type: "backgroundSelect",
        fieldProps: {
          filterOptions: ["image"],
        },
        defaultValue: {
          type: "color",
          color: "#fff",
        }
      },
      {
        label: "背景透明度",
        prop: "tooltipBackgroudOpacity",
        type: "slider",
        defaultValue: 100
      },
      {
        label: "阴影",
        prop: "tooltipShadow",
        type: "radioGroup",
        fieldProps: {
          options: [
            { label: "开启", value: true },
            { label: "关闭", value: false },
          ],
        },
        defaultValue: false
      },
    ]
  },
  {
    label: "背景",
    prop: "background",
    type: "group",
    children: [
      {
        label: "边框",
        prop: "",
        type: "divider",
      },
      {
        label: "线宽",
        prop: "backgroundBorderWidth",
        type: "inputNumber",
        fieldProps: {
          addonAfter: "px",
        },
        defaultValue: 0
      },
      {
        label: "颜色",
        prop: "backgroundBorderColor",
        type: "colorSelect",
        defaultValue: "#ccc"
      },
      {
        label: "圆角",
        prop: "backgroundBorderRadius",
        type: "inputNumber",
        fieldProps: {
          addonAfter: "px",
        },
        defaultValue: 0
      },
      {
        label: "背景",
        prop: "",
        type: "divider",
      },
      {
        label: "填充",
        prop: "backgroundBackground",
        type: "backgroundSelect",
        fieldProps: {
          filterOptions: ["image"],
        },
        defaultValue: {
          type: "color",
          color: "#fff",
        }
      },
      {
        label: "背景透明度",
        prop: "backgroundBackgroudOpacity",
        type: "slider",
        defaultValue: 100
      },
      {
        label: "阴影",
        prop: "backgroundShadow",
        type: "radioGroup",
        fieldProps: {
          options: [
            { label: "开启", value: true },
            { label: "关闭", value: false },
          ],
        },
        defaultValue: false
      },
    ]
  }
];
